@@ -157,6 +157,7 @@ end
 
 local function fuzzy_match_items(items, needle, files)
   local res = {}
+  needle = (PLATFORM == "Windows" and files) and needle:gsub('/', PATHSEP) or needle
   for _, item in ipairs(items) do
     local score = system.fuzzy_match(tostring(item), needle, files)
     if score then
@@ -226,7 +227,12 @@ function common.path_suggest(text, root)
   if root and root:sub(-1) ~= PATHSEP then
     root = root .. PATHSEP
   end
-  local path, name = text:match("^(.-)([^"..PATHSEP.."]*)$")
+
+  local pathsep = PATHSEP
+  if PLATFORM == "Windows" then
+    pathsep = "\\/"
+  end
+  local path = text:match("^(.-)[^"..pathsep.."]*$")
   local clean_dotslash = false
   -- ignore root if path is absolute
   local is_absolute = common.is_absolute_path(text)
